"""NDG OAuth Client ndg.oauth namespace package for server code

This is a setuptools namespace_package.  DO NOT place any other
code in this file!  There is no guarantee that it will be installed
with easy_install.  See:

http://peak.telecommunity.com/DevCenter/setuptools#namespace-packages

... for details.
"""
__author__ = "P J Kershaw"
__date__ = "09/07/12"
__copyright__ = "(C) 2012 Science and Technology Facilities Council"
__license__ = "BSD - see LICENSE file in top-level directory"
__contact__ = "Philip.Kershaw@stfc.ac.uk"
__revision__ = '$Id$'

__import__('pkg_resources').declare_namespace(__name__)
